import _ from 'lodash';
import { Component, ViewChild, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { DatagridModule } from '@farris/ui-datagrid';
import { DatagridEditorsModule, EditorProviders } from '@farris/ui-datagrid-editors';
import { ListNavModule } from '@farris/ui-list-nav';
import { ListViewModule } from '@farris/ui-list-view';
import { ComboListModule } from '@farris/ui-combo-list';
import { FarrisSectionModule } from '@farris/ui-section';
import { HttpService } from '@ecp-caf/caf-common';
import { FarrisSidebarModule } from '@farris/ui-sidebar';
import { FarrisFormsModule } from '@farris/ui-forms';
import { ModalModule, BsModalService } from '@farris/ui-modal';
import { FormsModule } from '@angular/forms';
import { MessagerModule } from '@farris/ui-messager';
import { NotifyModule } from '@farris/ui-notify';
import { ViewChangeModule } from '@farris/ui-view-change';
import { FarrisDatePickerModule } from '@farris/ui-datepicker';
import { InputGroupModule } from '@farris/ui-input-group';
import { FarrisTabsModule } from '@farris/ui-tabs';
import { TreeTableModule } from '@farris/ui-treetable';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const RecipientType = {
    Organize: 0,
    Position: 1,
    User: 2,
};
RecipientType[RecipientType.Organize] = 'Organize';
RecipientType[RecipientType.Position] = 'Position';
RecipientType[RecipientType.User] = 'User';
class Result {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MessageUserSelectorComponent {
    /**
     * @param {?} http
     */
    constructor(http) {
        this.http = http;
        this.columns = [];
        this.treedata = []; //当前所有组织信息
        //当前所有组织信息
        this.groupIcon = '<span class="f-icon f-icon-search"></span>';
        this.searchText = "";
        this.orgList = [];
        this.posList = [];
        //orgInfos=[];
        this.userInfos = []; //当前所有用户信息
        //当前所有用户信息
        this.recipientInfos = []; //已选用户信息
        //已选用户信息
        this.orgItems = []; //数据绑定数据
        //数据绑定数据
        this.posItems = []; //组织绑定数据
        //全选标识
        this.orgUserCount = 0;
        this.posuserCount = 0;
        this.isChildren = false; //组织根据是否进到子级分别显示
        //组织根据是否进到子级分别显示
        this.tabsLebel = "Organize"; //tab选择标识
        //tab选择标识
        this.selectedData = []; //右侧选择数据集
        //右侧选择数据集
        this.selectedAllCount = 0; //已选择总项
        //已选择总项
        this.selectedUserCount = 0; //已选择人数
        //已选择人数
        this.selectedOrgCount = 0; //已选择组织数
        //已选择组织数
        this.selectedPosCount = 0; //已选择岗位数
        //外部注入数据
        this.hasExpandOrg = [];
        this.imgSrc = '/platform/runtime/msg/web/message-center/assets/message-center-icon/default-user.svg';
        //用户字段格式
        this.UserFieldFormatter = (/**
         * @param {?} val
         * @param {?} data
         * @return {?}
         */
        (val, data) => {
            if (data.recipientType == 2) {
                return '<div class="align-items-center d-flex"><img class="ap-img" height="25" width="25" src="/platform/runtime/msg/web/message-center/assets/message-center-icon/default-user.svg">&nbsp;' + data.name + '</div>';
            }
            else
                return data.name;
        });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.hasExpandOrg = [];
        this.columns = [
            { field: 'name', title: "名称", width: 80, formatter: this.UserFieldFormatter },
        ];
        /** @type {?} */
        const landUser = ((/** @type {?} */ (top.window))).gspframeworkService.common.userInfos.get();
        this.sysOrgRoot = {
            data: {
                "id": landUser.tenantId,
                "code": landUser.tenantId,
                "name": landUser.tenantName,
                "parentId": "",
                "parentName": "",
                "isDetail": false,
                "recipientType": RecipientType.Organize,
                "userNumber": 0,
            },
            parent: null,
            children: [],
            expanded: true
        };
        this.treedata.push(this.sysOrgRoot);
        this.orgList.push(this.sysOrgRoot);
        this.convertOrgTree();
        this.convertPosTree();
        this.selectedData = [];
    }
    //核心数据转化
    /**
     * @return {?}
     */
    convertOrgTree() {
        this.getOrgsByLayer(1).subscribe((/**
         * @param {?} orgs
         * @return {?}
         */
        (orgs) => {
            if (orgs) {
                orgs.forEach((/**
                 * @param {?} item
                 * @return {?}
                 */
                item => {
                    if (item.code !== "25") {
                        /** @type {?} */
                        let org = {
                            data: {
                                "id": item.id,
                                "code": item.code,
                                "name": item.name,
                                "parentId": item.parentId,
                                "isDetail": item.isDetail,
                                "recipientType": RecipientType.Organize,
                                "userNumber": 0,
                                "parentName": ""
                            },
                            parent: null,
                            children: [],
                            expanded: false
                        };
                        /** @type {?} */
                        let orgChild = {
                            data: {
                                "id": this.newGuid(),
                                "code": "",
                                "name": "",
                                "parentId": "",
                                "isDetail": true,
                                "recipientType": RecipientType.User,
                                "userNumber": 0,
                                "parentName": "",
                                "children": [],
                            },
                            parent: org,
                            children: [],
                            expanded: false
                        };
                        org.children.push(orgChild);
                        org.data.parentName = this.sysOrgRoot.name;
                        this.sysOrgRoot.children.push(org);
                        this.orgItems.push(org);
                    }
                }));
                this.treedata = [...this.treedata];
                this.orgList;
                //注入数据显示
                if (this.injectorData && this.injectorData != "") {
                    /** @type {?} */
                    let showDatas = JSON.parse(this.injectorData);
                    showDatas.forEach((/**
                     * @param {?} item
                     * @return {?}
                     */
                    item => {
                        if (item.recipientType == 0) {
                            this.getUsersByOrgId(item.id).subscribe((/**
                             * @param {?} users
                             * @return {?}
                             */
                            users => {
                                /** @type {?} */
                                let orgUserItem = this.orgItems.find((/**
                                 * @param {?} data
                                 * @return {?}
                                 */
                                data => data.data.id === item.id && data.data.recipientType == 0));
                                if (orgUserItem) {
                                    orgUserItem.data.userNumber = users.totalCount;
                                    this.selectedData.push(orgUserItem.data);
                                }
                                else {
                                    this.selectedData.push({
                                        "id": item.id,
                                        "name": item.name,
                                        "recipientType": item.recipientType,
                                        "userNumber": users.totalCount
                                    });
                                }
                                this.selectedOrgCount++;
                                this.selectedAllCount++;
                            }));
                        }
                        if (item.recipientType == 1) {
                            this.getPosByPosId(item.id).subscribe((/**
                             * @param {?} poss
                             * @return {?}
                             */
                            poss => {
                                /** @type {?} */
                                let pos = poss[0];
                                /** @type {?} */
                                let posItem = {
                                    "id": pos.id,
                                    "code": pos.code,
                                    "name": pos.name,
                                    "parentId": "",
                                    "isDetail": true,
                                    "recipientType": RecipientType.Position,
                                    "userNumber": 0,
                                    "parentName": "",
                                    "children": [],
                                };
                                this.selectedData.push(posItem);
                                this.selectedPosCount++;
                                this.selectedAllCount++;
                            }));
                        }
                        if (item.recipientType == 2) {
                            this.getUserById(item.id).subscribe((/**
                             * @param {?} users
                             * @return {?}
                             */
                            users => {
                                /** @type {?} */
                                let user = users[0];
                                /** @type {?} */
                                let orgUserItem = {
                                    "id": user.id,
                                    "code": user.code,
                                    "name": user.name,
                                    "parentId": "",
                                    "isDetail": true,
                                    "recipientType": RecipientType.User,
                                    "userNumber": 0,
                                    "parentName": user.sysOrgName,
                                    "children": [],
                                };
                                this.selectedData.push(orgUserItem);
                                this.selectedUserCount++;
                                this.selectedAllCount++;
                            }));
                        }
                    }));
                    this.selectedData = [...this.selectedData];
                }
            }
        }));
    }
    /**
     * @return {?}
     */
    convertPosTree() {
        this.getAllPoss().subscribe((/**
         * @param {?} poss
         * @return {?}
         */
        (poss) => {
            poss.forEach((/**
             * @param {?} element
             * @return {?}
             */
            element => {
                /** @type {?} */
                let showDatas;
                /** @type {?} */
                let posInfo = {
                    data: {
                        "id": element.id,
                        "code": element.code,
                        "name": element.name,
                        "parentId": "",
                        "parentName": "",
                        "isDetail": false,
                        "recipientType": RecipientType.Position,
                        "userNumber": 0,
                        "children": [],
                    },
                    parent: null,
                    children: [],
                    expanded: false
                };
                /** @type {?} */
                let posChild = {
                    data: {
                        "id": this.newGuid(),
                        "code": "",
                        "name": "",
                        "parentId": "",
                        "isDetail": true,
                        "recipientType": RecipientType.User,
                        "userNumber": 0,
                        "parentName": "",
                        "children": [],
                    },
                    parent: posInfo,
                    children: [],
                    expanded: false
                };
                posInfo.children.push(posChild);
                this.posItems.push(posInfo);
                if (this.injectorData && this.injectorData != "") {
                    showDatas = JSON.parse(this.injectorData);
                }
            }));
            this.posItems = [...this.posItems];
        }));
    }
    /**
     * @return {?}
     */
    clearCheckeds() {
        this.orgsComponent.clearCheckeds();
    }
    /**
     * @return {?}
     */
    getResult() {
        /** @type {?} */
        let results = [];
        if (this.selectedData && this.selectedData.length > 0) {
            this.selectedData.forEach((/**
             * @param {?} item
             * @return {?}
             */
            item => {
                /** @type {?} */
                let result = new Result;
                result.id = item.id;
                result.name = item.name;
                result.recipientType = item.recipientType;
                results.push(result);
            }));
        }
        return JSON.stringify(results);
    }
    /**
     * @return {?}
     */
    getSelectedUsers() {
        if (this.selectedData && this.selectedData.length > 0) {
            /** @type {?} */
            let results = [];
            this.selectedData.forEach((/**
             * @param {?} item
             * @return {?}
             */
            item => {
                if (item.recipientType == 2) {
                    if (!results.includes(item.id)) {
                        results.push(item.id);
                    }
                }
                else if (item.recipientType == 0) {
                    // this.getUsersByOrgId(item.id).subscribe(users=>{
                    //   users.data.forEach(user=>{
                    //     if(!results.includes(user.id)){
                    //       results.push(user.id);
                    //     };
                    //   });
                    // });
                    if (item.children && item.children.length > 0) {
                        item.children.forEach((/**
                         * @param {?} item
                         * @return {?}
                         */
                        item => {
                            if (!results.includes(item)) {
                                results.push(item);
                            }
                        }));
                    }
                }
            }));
            return JSON.stringify(results);
            // let orgs = this.selectedData.filter(item=>item.recipientType==1);
            // if(orgs && orgs.length>0){
            //   orgs.forEach(item=>{
            //     this.getAllUsersByPosId(item.id).subscribe((users)=>{
            //       users.children.forEach(user=>{
            //         if(!results.includes(user.id)){
            //           results.push(user.id);
            //         };
            //       })
            //     })
            //   });
            // }
            // else{
            //   this.selectedData.forEach(item=>{
            //     if(item.recipientType==2){ 
            //       if(!results.includes(item.id)){
            //         results.push(item.id);
            //       };
            //     }
            //     else if(item.recipientType==1){
            //     }
            //   });
            // }
        }
    }
    /**
     * @private
     * @param {?} children
     * @return {?}
     */
    getChildSet(children) {
        /** @type {?} */
        let list = [];
        children.forEach((/**
         * @param {?} item
         * @return {?}
         */
        item => {
            if (item.recipientType == 2) {
                if (!list.includes(item.id)) {
                    list.push(item.id);
                }
            }
            else if (item.recipientType == 0) {
                this.getChildSet(item.children).forEach((/**
                 * @param {?} userId
                 * @return {?}
                 */
                userId => {
                    if (!list.includes(userId)) {
                        list.push(userId);
                    }
                }));
            }
        }));
        return list;
    }
    //删除某一个选择项
    /**
     * @param {?} $event
     * @return {?}
     */
    delete($event) {
        /** @type {?} */
        var item = {
            node: {
                id: $event.id,
                data: $event
            }
        };
        this.nodeUnChecked(item);
    }
    //清空所选数据
    /**
     * @return {?}
     */
    clearSelectedData() {
        this.selectedData = [];
        this.selectedAllCount = 0;
        this.selectedOrgCount = 0;
        this.selectedPosCount = 0;
        this.selectedUserCount = 0;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    tabChange($event) {
        this.tabsLebel = $event.nextId;
        this.checkAllList = false;
        if (this.tabsLebel === "Organize") {
            this.orgsComponent.clearCheckeds();
        }
        else if (this.tabsLebel === "Position") {
            this.possComponent.clearCheckeds();
        }
        this.searchText = "";
    }
    //选择统计数加1
    /**
     * @private
     * @param {?} recipientType
     * @return {?}
     */
    addSelectedOrgUserCount(recipientType) {
        if (recipientType == 0) {
            this.selectedOrgCount++;
            this.selectedAllCount++;
        }
        else if (recipientType == 1) {
            this.selectedPosCount++;
            this.selectedAllCount++;
        }
        else if (recipientType == 2) {
            this.selectedUserCount++;
            this.selectedAllCount++;
        }
    }
    //选择统计数减1
    /**
     * @private
     * @param {?} recipientType
     * @return {?}
     */
    removeSelectedOrgUserCount(recipientType) {
        if (recipientType == 0) {
            if (this.selectedOrgCount > 0) {
                this.selectedOrgCount--;
            }
            if (this.selectedAllCount > 0) {
                this.selectedAllCount--;
            }
        }
        else if (recipientType == 1) {
            if (this.selectedPosCount > 0) {
                this.selectedPosCount--;
            }
            if (this.selectedAllCount > 0) {
                this.selectedAllCount--;
            }
        }
        else if (recipientType == 2) {
            if (this.selectedUserCount > 0) {
                this.selectedUserCount--;
            }
            if (this.selectedAllCount > 0) {
                this.selectedAllCount--;
            }
        }
    }
    //搜索框事件
    /**
     * @return {?}
     */
    clear() {
        if (this.tabsLebel === "Organize") {
            this.treedata = [...this.orgList];
        }
        else {
            this.posItems = [...this.posList];
        }
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onChange($event) {
        if ($event) {
            if (this.tabsLebel === "Organize") {
                this.treedata = [];
                /** @type {?} */
                let navTemp = _.cloneDeep(this.orgList);
                this.treedata = this.matchFindText(navTemp, $event);
                this.treedata = [...this.treedata];
            }
            else {
                this.posItems = [];
                /** @type {?} */
                let navTemp = _.cloneDeep(this.posList);
                this.posItems = this.matchFindText(navTemp, $event);
                this.posItems = [...this.posItems];
            }
        }
        else {
            this.clear();
        }
    }
    /**
     * @param {?} nodes
     * @param {?} text
     * @return {?}
     */
    matchFindText(nodes, text) {
        /** @type {?} */
        let xNodes = [];
        nodes.forEach((/**
         * @param {?} node
         * @return {?}
         */
        node => {
            if (node.children && node.children.length > 0) {
                /** @type {?} */
                let xxNodes = this.matchFindText(node.children, text);
                if (xxNodes && xxNodes.length > 0) {
                    node.children = xxNodes;
                    xNodes.push(node);
                }
                else {
                    if (node.data.name.search(text) != -1) {
                        xNodes.push(node);
                    }
                }
            }
            else {
                if (node.data.name.search(text) != -1) {
                    xNodes.push(node);
                }
            }
        }));
        return xNodes;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    nodeChecked($event) {
        /** @type {?} */
        let findIndex = this.selectedData.findIndex((/**
         * @param {?} data
         * @return {?}
         */
        data => data.id === $event.node.id && data.recipientType === $event.node.data.recipientType));
        if (findIndex < 0) {
            /** @type {?} */
            let node = $event.node;
            if (node.data.recipientType == 0) {
                this.getAllUsersByOrgIdWithNext(node.data.id).subscribe((/**
                 * @param {?} users
                 * @return {?}
                 */
                (users) => {
                    node.data.userNumber = users.totalCount;
                    /** @type {?} */
                    let list = [];
                    users.data.forEach((/**
                     * @param {?} user
                     * @return {?}
                     */
                    user => {
                        list.push(user.id);
                    }));
                    node.data.children = list;
                    this.selectedData.push(node.data);
                    this.selectedData = [...this.selectedData];
                    this.addSelectedOrgUserCount(node.data.recipientType);
                }));
            }
            else if (node.data.recipientType == 2) {
                this.selectedData.push(node.data);
                this.selectedData = [...this.selectedData];
                this.addSelectedOrgUserCount(node.data.recipientType);
            }
        }
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    nodeUnChecked($event) {
        /** @type {?} */
        let findIndex = this.selectedData.findIndex((/**
         * @param {?} data
         * @return {?}
         */
        data => data.id === $event.node.id && data.recipientType === $event.node.data.recipientType));
        if (findIndex == 0) {
            this.selectedData.shift();
            this.removeSelectedOrgUserCount($event.node.data.recipientType);
        }
        else if (findIndex == this.selectedData.length - 1) {
            this.selectedData.pop();
            this.removeSelectedOrgUserCount($event.node.data.recipientType);
        }
        else if (0 < findIndex && findIndex < this.selectedData.length - 1) {
            /** @type {?} */
            let front = this.selectedData.slice(0, findIndex);
            /** @type {?} */
            let back = this.selectedData.slice(findIndex + 1, this.selectedData.length);
            this.selectedData = front.concat(back);
            this.removeSelectedOrgUserCount($event.node.data.recipientType);
        }
        this.selectedData = [...this.selectedData];
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    expandOrg($event) {
        if ($event.parent) {
            if (this.tabsLebel === "Organize") {
                /** @type {?} */
                let expandOrg = this.hasExpandOrg.find((/**
                 * @param {?} item
                 * @return {?}
                 */
                item => item == $event.data.id));
                if (!expandOrg) {
                    $event.children = [];
                    // this.treedata = [...this.treedata];
                    this.getAllUsersByOrgId($event.data.id).subscribe((/**
                     * @param {?} users
                     * @return {?}
                     */
                    (users) => {
                        $event.data.userNumber = users.totalCount;
                        /** @type {?} */
                        let list = [];
                        users.data.forEach((/**
                         * @param {?} user
                         * @return {?}
                         */
                        user => {
                            /** @type {?} */
                            let userInfo = {
                                data: {
                                    "id": user.id,
                                    "code": user.code,
                                    "name": user.name,
                                    "parentId": user.sysOrgId,
                                    "parentName": $event.data.name,
                                    "isDetail": true,
                                    "recipientType": RecipientType.User,
                                    "userNumber": 0,
                                },
                                parent: $event,
                                children: [],
                                expanded: false
                            };
                            list.push(userInfo);
                            // $event.children.push(userInfo);
                        }));
                        this.orgsComponent.appendChildren(list, $event);
                        // this.treedata = [...this.treedata];
                    }));
                    this.getOrgsByParentId($event.data.id).subscribe((/**
                     * @param {?} orgs
                     * @return {?}
                     */
                    (orgs) => {
                        if (orgs) {
                            /** @type {?} */
                            let list = [];
                            orgs.forEach((/**
                             * @param {?} item
                             * @return {?}
                             */
                            item => {
                                /** @type {?} */
                                let org = {
                                    data: {
                                        "id": item.id,
                                        "code": item.code,
                                        "name": item.name,
                                        "parentId": item.parentId,
                                        "isDetail": item.isDetail,
                                        "recipientType": RecipientType.Organize,
                                        "userNumber": 0,
                                        "parentName": "",
                                    },
                                    parent: $event,
                                    children: [],
                                    expanded: false
                                };
                                /** @type {?} */
                                let orgChild = {
                                    data: {
                                        "id": this.newGuid(),
                                        "code": "",
                                        "name": "",
                                        "parentId": "",
                                        "isDetail": true,
                                        "recipientType": RecipientType.User,
                                        "userNumber": 0,
                                        "parentName": "",
                                        "children": [],
                                    },
                                    parent: org,
                                    children: [],
                                    expanded: false
                                };
                                org.children.push(orgChild);
                                list.push(org);
                                // $event.children.push(org);
                            }));
                            this.orgsComponent.appendChildren(list, $event);
                            // this.treedata = [...this.treedata];
                        }
                    }));
                    this.hasExpandOrg.push($event);
                    // this.treedata = [...this.treedata];
                }
            }
            else {
                $event.children = [];
                this.posItems = [...this.posItems];
                this.getAllUsersByPosId($event.data.id).subscribe((/**
                 * @param {?} users
                 * @return {?}
                 */
                (users) => {
                    $event.data.userNumber = users.length;
                    users.forEach((/**
                     * @param {?} user
                     * @return {?}
                     */
                    user => {
                        /** @type {?} */
                        let userInfo = {
                            data: {
                                "id": user.id,
                                "code": user.code,
                                "name": user.name,
                                "parentId": user.sysOrgId,
                                "parentName": $event.data.name,
                                "isDetail": true,
                                "recipientType": RecipientType.User,
                                "userNumber": 0,
                            },
                            parent: $event,
                            children: [],
                            expanded: false
                        };
                        $event.children.push(userInfo);
                    }));
                    this.posItems = [...this.posItems];
                    // this.posList = _.cloneDeep(this.posItems);
                    //注入数据显示
                    // if(showDatas && showDatas.length>0){
                    //   let posItem = showDatas.find(item=>item.id===posInfo.data.id && item.recipientType==1);
                    //   if(posItem){
                    //     this.selectedData.push(posInfo.data);
                    //     this.selectedData = [...this.selectedData]; 
                    //     this.selectedPosCount++;
                    //     this.selectedAllCount++;
                    //   }
                    // }
                }));
            }
        }
    }
    //自动生成随机码
    /**
     * @private
     * @return {?}
     */
    newGuid() {
        /** @type {?} */
        const initString = 'xxxx-xx';
        /** @type {?} */
        const result = initString.replace(/[xy]/g, (/**
         * @param {?} c
         * @return {?}
         */
        (c) => {
            return this.convert(c);
        }));
        return result;
    }
    /**
     * @private
     * @param {?} c
     * @return {?}
     */
    convert(c) {
        /** @type {?} */
        const r = Math.random() * 16 | 0;
        /** @type {?} */
        const v = c === 'x' ? r : (r & 0x3 | 0x8);
        return v.toString(16);
    }
    /**
     * @private
     * @param {?} id
     * @return {?}
     */
    getUserById(id) {
        /** @type {?} */
        let url = "/api/runtime/sys/v1.0/users/" + id;
        return this.http.get(url);
    }
    /**
     * @private
     * @param {?} id
     * @return {?}
     */
    getUsersByOrgId(id) {
        /** @type {?} */
        let url = "/api/runtime/sys/v1.0/users?param={\"orgId\":\"" + id + "\"}";
        return this.http.get(url);
    }
    /**
     * @private
     * @param {?} layer
     * @return {?}
     */
    getOrgsByLayer(layer) {
        /** @type {?} */
        let url = "/api/runtime/sys/v1.0/sysOrgs?param={\"layer\":\"" + layer + "\"}";
        return this.http.get(url);
    }
    /**
     * @private
     * @param {?} id
     * @return {?}
     */
    getOrgsByParentId(id) {
        /** @type {?} */
        let url = "/api/runtime/sys/v1.0/sysOrgs?param={\"parentId\":\"" + id + "\"}";
        return this.http.get(url);
    }
    // private getAllUsersByOrgId(id:String): Observable<any> {
    //   return this.http.post('/api/runtime/sys/v1.0/messagecenter/recipicent/orguser',id);
    // }
    /**
     * @private
     * @param {?} id
     * @return {?}
     */
    getAllUsersByOrgId(id) {
        /** @type {?} */
        let url = "/api/runtime/sys/v1.0/users?param={\"orgId\":\"" + id + "\",\"withAllOrg\":false}";
        return this.http.get(url);
    }
    /**
     * @private
     * @return {?}
     */
    getAllPoss() {
        return this.http.get('/api/runtime/sys/v1.0/messagecenter/recipicent/allposs');
    }
    /**
     * @private
     * @param {?} id
     * @return {?}
     */
    getAllUsersByPosId(id) {
        return this.http.post('/api/runtime/sys/v1.0/messagecenter/recipicent/posuser', id);
    }
    /**
     * @private
     * @param {?} id
     * @return {?}
     */
    getPosByPosId(id) {
        return this.http.get('/api/runtime/sys/v1.0/positions/' + id);
    }
    /**
     * @private
     * @param {?} id
     * @return {?}
     */
    getAllUsersByOrgIdWithNext(id) {
        /** @type {?} */
        let url = "/api/runtime/sys/v1.0/users?param={\"orgId\":\"" + id + "\"}";
        return this.http.get(url);
    }
}
MessageUserSelectorComponent.decorators = [
    { type: Component, args: [{
                selector: 'message-user-selector',
                template: "<div id=\"select\" class=\"f-utils-fill\" style=\"height:100%\">\r\n    <div id=\"left\" style=\"width:50%;height:100%;float:left;padding-left: 6px;\">\r\n      <div style=\"border:1px solid rgb(235, 233, 233);padding: 4px;height:100%\">\r\n        <farris-tabs style=\"height:100%\" [value]=\"'Organize'\" [contentFill]=\"true\" [showDropDown]=\"false\" (tabChange)=\"tabChange($event)\">\r\n            <farris-tab title=\"\u6700\u8FD1\" [id]=\"'Common'\">\r\n                <ng-template #content>\r\n                    <div style=\"height:100%\">\r\n                      \r\n                    </div>\r\n                </ng-template>\r\n            </farris-tab>\r\n            <farris-tab title=\"\u7EC4\u7EC7\u7ED3\u6784\" [id]=\"'Organize'\">\r\n                <ng-template #content>\r\n                    <div style=\"height:100%\">\r\n                      <!-- <ol class=\"breadcrumb\" style=\"margin-bottom:5px;padding:10px\">\r\n                          <div *ngFor=\"let organize of selectOrganizes; let i = index;let last = last;\">\r\n                              <div *ngIf=\"!last\">\r\n                                  <li class=\"breadcrumb-item\">\r\n                                      <a href=\"javascript: void(0);\" (click)=\"selectOrg(organize,i)\">{{organize.name}}&nbsp;>&nbsp;</a>\r\n                                  </li>\r\n                              </div>\r\n                          <li *ngIf=\"last\" class=\"breadcrumb-item active\" aria-current=\"page\">{{organize.name}}</li>\r\n                          </div>\r\n                      </ol> -->\r\n                      <!-- <div class=\"custom-control custom-checkbox custom-control-inline\" style=\"margin-bottom:5px;margin-left:10px\">\r\n                              <input type=\"checkbox\" class=\"custom-control-input\" [(ngModel)]=\"checkAllList\"\r\n                                  (click)=\"selectAll()\" id=\"selectAllList\">\r\n                              <label class=\"custom-control-label\" for=\"selectAllList\">&nbsp;&nbsp;&nbsp;&nbsp;\u5168\u9009({{orgUserCount}}\u4EBA)</label>\r\n                      </div> -->\r\n                      <input-group class=\"myinput\" [groupText]=\"groupIcon\" [(value)]=\"searchText\"\r\n                                  (valueChange)=\"onChange($event)\" (clear)=\"clear()\"></input-group>\r\n                      <div style=\"height:300px;width: 100%;\">\r\n                      \r\n                      <farris-treetable #orgs class=\"f-componet-treetable\" \r\n                      [data]=\"treedata\" \r\n                      [columns]=\"columns\" \r\n                      [idField]=\"'id'\"\r\n                      [showFilterBar]=\"false\" \r\n                      [fixedHeader]=\"true\" \r\n                      [fit]=\"true\" \r\n                      [fitColumns]=\"false\" \r\n                      [striped]=\"true\"\r\n                      [showBorder]=\"false\"\r\n                      [singleSelect]=\"false\"\r\n                      [checkOnSelect]=\"false\" \r\n                      [selectOnCheck]=\"false\"\r\n                      [showCheckbox]=\"true\"\r\n                      [cascadeCheck]=\"false\"\r\n                      [virtualized]=\"true\"\r\n                      (nodeChecked)=\"nodeChecked($event)\"\r\n                      (nodeUnChecked)=\"nodeUnChecked($event)\"\r\n                      (expand)=\"expandOrg($event)\"\r\n                      >\r\n                      </farris-treetable>\r\n                      </div>\r\n                    </div>\r\n                </ng-template>\r\n            </farris-tab>\r\n            <!-- <farris-tab title=\"\u5C97\u4F4D\u7C7B\u578B\" [id]=\"'Position'\">\r\n                <ng-template #content>\r\n                    <div style=\"height:100%\">\r\n                      <input-group class=\"myinput\" [groupText]=\"groupIcon\" [(value)]=\"searchText\"\r\n                      (valueChange)=\"onChange($event)\" (clear)=\"clear()\"></input-group>\r\n                      <div style=\"height:290px;width: 100%;\">\r\n                      \r\n                      <farris-treetable #poss class=\"f-componet-treetable\" \r\n                      [data]=\"posItems\" \r\n                      [columns]=\"columns\" \r\n                      [idField]=\"'id'\"\r\n                      [showFilterBar]=\"false\" \r\n                      [fixedHeader]=\"true\" \r\n                      [fit]=\"true\" \r\n                      [fitColumns]=\"false\" \r\n                      [striped]=\"true\"\r\n                      [showBorder]=\"false\"\r\n                      [showHeader]=\"false\"\r\n                      [singleSelect]=\"false\"\r\n                      [checkOnSelect]=\"true\" \r\n                      [selectOnCheck]=\"false\"\r\n                      [showCheckbox]=\"true\"\r\n                      [cascadeCheck]=\"false\"\r\n                      [virtualized]=\"true\"\r\n                      (nodeChecked)=\"nodeChecked($event)\"\r\n                      (nodeUnChecked)=\"nodeUnChecked($event)\"\r\n                      (expand)=\"expandOrg($event)\"\r\n                      >\r\n                      </farris-treetable>\r\n                      </div>\r\n                    </div>\r\n                </ng-template>\r\n            </farris-tab>  -->\r\n        </farris-tabs>\r\n      </div>\r\n    </div>\r\n    <div id=\"right\" style=\"width:50%;height:100%;float: left;padding-left: 5px;padding-right: 6px;\">\r\n        <div style=\"border:1px solid rgb(235, 233, 233);padding: 4px;height:100%;\">\r\n              <div class=\"d-flex\" style=\"line-height:22px;margin-bottom:4px;line-height: 30px;padding-right:10px;padding-left:10px;\">\r\n                      <div class=\"listview-item-title f-utils-fill\" style=\"margin-bottom: 2px;\" >\r\n                          \u5DF2\u9009{{selectedAllCount}}\u9879\r\n                          <span style=\"font-size: 12px;padding-left:10px\">\r\n                              (\u4EBA{{selectedUserCount}}\uFF0C\u7EC4\u7EC7{{selectedOrgCount}}\uFF0C\u5C97\u4F4D{{selectedPosCount}})\r\n                          </span>\r\n                      </div>\r\n                      <div class=\"listview-item-time\" style=\"font-size: 13px;\">\r\n                          <a href=\"javascript:void(0);\" class=\"myclearall\" (click)=\"clearSelectedData()\">\u6E05\u7A7A\u5DF2\u9009</a>\r\n                      </div>\r\n              </div>\r\n              <farris-list-view #myListView [data]=\"selectedData\" [multipleSelect]=\"false\" [supportPaging]=\"false\" [fill]=\"true\">\r\n                      <ng-template listTemplate let-item=\"item\">\r\n                          <div class=\"f-template-common-row d-flex f-selector-listview-container\" style=\"margin-top: 5px;width: 100%\">\r\n                              <div *ngIf=\"item.recipientType==2\" class=\"item-action-primary\" style=\"margin-right: 15px;padding: top 5px;\">\r\n                                  <img [src]=\"imgSrc\" class=\"ap-img\" width=\"35\" height=\"35\">\r\n                              </div>\r\n                              <div *ngIf=\"item.recipientType==2\" class=\"listview-item-content d-flex k-align-items-center f-utils-fill\" style=\"border-bottom:1px solid #d9d9d9;padding-bottom: 5px;\">\r\n                                  <div class=\"listview-item-main f-utils-fill\">\r\n                                      <div class=\"d-flex\" style=\"line-height:25px;margin-bottom:0px;\">\r\n                                          <div class=\"listview-item-title f-utils-fill item-sender\" >\r\n                                              {{item.name}} &nbsp;<span style=\"font-size: 14px;color: rgb(190, 192, 196);\">{{item.code}}</span>\r\n                                          </div>\r\n                                          <div class=\"listview-item-time\">\r\n                                                  <span class=\"f-icon f-icon-close text-info\" (click)=\"delete(item)\"></span>\r\n                                          </div>\r\n                                      </div>\r\n                                      <div class=\"listview-item-mes\" style=\"font-size:12px;color: rgb(189, 191, 194);margin-top: 4px;\">\r\n                                              {{item.parentName}}\r\n                                      </div>\r\n                                  </div>\r\n                              </div>\r\n                              <div *ngIf=\"item.recipientType!==2\" class=\"listview-item-content d-flex k-align-items-center f-utils-fill\" style=\"border-bottom:1px solid #d9d9d9;padding-bottom: 5px;\">\r\n                                      <div class=\"listview-item-main f-utils-fill\">\r\n                                          <div class=\"d-flex\" style=\"line-height:22px;margin-bottom:0px;\">\r\n                                              <div class=\"listview-item-title f-utils-fill item-sender\" >\r\n                                                  &nbsp;&nbsp;{{item.name}}\uFF08\u5305\u542B{{item.userNumber}}\u4EBA\uFF09\r\n                                              </div>\r\n                                              <div class=\"listview-item-time\">\r\n                                                      <span class=\"f-icon f-icon-close text-info\" (click)=\"delete(item)\"></span>\r\n                                              </div>\r\n                                          </div>\r\n                                      </div>\r\n                              </div>\r\n                          </div>\r\n                      </ng-template>\r\n                  </farris-list-view>\r\n        </div>       \r\n    </div>\r\n  </div>",
                styles: [".template-step-footer{padding-top:6px;padding-bottom:6px}.step-progress{margin-top:5px;margin-left:20px}:host{flex:1 1 0;position:relative}.operator{padding-top:15px;padding-right:0;text-align:right;margin-bottom:8px}.template-fenge-line{border-top:1px dashed #ccd2e1;padding-top:15px;padding-right:0;text-align:right;margin-top:15px}.template-editor{margin-top:10px}.myclearall{margin-left:5px;text-decoration:none;text-align:center;color:#3b91ff;padding:right 8px}.item-sender{font-family:PingFangSC-Regular;font-size:18px;color:rgba(0,0,0,.85);text-align:left}.cbtn{background-image:linear-gradient(225deg,#49b4ff 0,#3b91ff 100%);border-radius:17px}.mylink{margin-left:5px;text-decoration:underline;text-align:center;color:#7480a6}.f-message-files{display:flex;flex-wrap:wrap}.f-message-files-item{display:flex;align-items:center;justify-content:space-between;width:150px;height:41px;min-height:40px;margin-right:10px;margin-bottom:0;padding-left:7px;background:#fff;border:1px solid #d9dfe6;box-shadow:0 2px 10px 0 rgba(0,32,74,.04);border-radius:6px}.f-message-files-item .file-item-left{display:flex;align-items:flex-start}.f-message-files-item .file-item-left .file-item-img{width:20px;margin-top:6px}.f-message-files-item .file-item-left .file-item-img img{display:block;width:20px;height:24px}.f-message-files-item .file-item-left .file-item-text{margin-left:10px}.f-message-files-item .file-item-left .file-item-text .file-item-name{margin-bottom:0;line-height:20px;font-size:14px;color:rgba(0,0,0,.85);white-space:nowrap;text-overflow:ellipsis;overflow:hidden}.f-message-files-item .file-item-left .file-item-text .file-item-size{font-size:12px;color:rgba(0,0,0,.45)}.f-message-files-item .file-item-right{display:flex;align-items:center}.f-message-files-item .file-item-right .file-item-btn{padding:0 8px;line-height:58px;cursor:pointer}.f-message-files-item .file-item-right .file-item-btn .f-icon{font-size:10px;color:#4d97ff}.f-message-files-item .file-item-right .file-item-btn:hover .f-icon{color:#2a87ff}.f-selector-listview-container .item-sender{font-family:PingFangSC-Regular;font-size:14px;color:rgba(0,0,0,.85);text-align:left}.myinput{margin-bottom:6px}"]
            }] }
];
/** @nocollapse */
MessageUserSelectorComponent.ctorParameters = () => [
    { type: HttpService }
];
MessageUserSelectorComponent.propDecorators = {
    orgsComponent: [{ type: ViewChild, args: ['orgs',] }],
    possComponent: [{ type: ViewChild, args: ['poss',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MessageUserSelectorModule {
}
MessageUserSelectorModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MessageUserSelectorComponent],
                imports: [
                    CommonModule,
                    ListNavModule,
                    ListViewModule,
                    FarrisSectionModule,
                    FarrisSidebarModule,
                    ComboListModule,
                    FarrisFormsModule,
                    FormsModule,
                    ModalModule.forRoot(),
                    DatagridEditorsModule,
                    MessagerModule,
                    NotifyModule,
                    ViewChangeModule,
                    InputGroupModule,
                    FarrisDatePickerModule,
                    FarrisTabsModule,
                    TreeTableModule,
                    DatagridModule.forRoot([
                        ...EditorProviders
                    ])
                ],
                entryComponents: [MessageUserSelectorComponent],
                exports: [MessageUserSelectorComponent],
                providers: [BsModalService, HttpService]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { MessageUserSelectorComponent, MessageUserSelectorModule };

//# sourceMappingURL=gsp-svc-message-user-selector.js.map